Module ir

Module ir 

Typed, topologically ordered intermediate representations for kernels.

Re-exports

pub use crate::KernelIrError;

Structs

CacheKernelIr
Validated IR for a kernel that populates multiple cache outputs.
GradientKernelIr
Validated IR containing a primal computation and real gradient outputs.
KernelIrBuilder
Builder for appending type-checked instructions to existing scalar IR.
KernelValue
Typed instruction and evaluation class for one kernel IR value.
KernelValueId
Stable identifier for a value in kernel IR.
ScalarKernelIr
Validated IR for a kernel with one scalar output.

Enums

KernelInstruction
Operation that produces one value in kernel IR.
KernelValueClass
Whether a kernel value is constant across events or event-dependent.
KernelValueKind
Runtime shape and scalar representation of a kernel value.
OutputComponent
Scalar component of a complex primal output to differentiate.