GradientKernelIr

Struct GradientKernelIr 

pub struct GradientKernelIr { /* private fields */ }
Validated IR containing a primal computation and real gradient outputs.

Implementations

Source

impl GradientKernelIr

pub fn new( values: Vec<KernelValue>, primal_root: KernelValueId, outputs: Vec<KernelValueId>, component: OutputComponent, ) -> Result<Self, KernelIrError>

Validates and constructs a gradient kernel.

Errors

Returns KernelIrError when the primal IR is invalid, the primal root is not scalar, a gradient output is out of bounds, or a gradient output is not real-valued.

pub fn validate(&self) -> Result<(), KernelIrError>

Revalidates the primal root and real gradient outputs.

Errors

Returns KernelIrError when the primal IR is invalid, the primal root is not scalar, a gradient output is out of bounds, or a gradient output is not real-valued.

pub fn values(&self) -> &[KernelValue]

Returns all primal and derivative IR values in topological order.

pub fn primal_root(&self) -> KernelValueId

Returns the primal scalar output identifier.

pub fn outputs(&self) -> &[KernelValueId]

Returns derivative output identifiers.

pub fn component(&self) -> OutputComponent

Returns the differentiated component of the complex primal.